@@ -4,8 +4,6 @@ use std::ops::Deref;
 use std::str::FromStr;
 use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
 use std::sync::Arc;
-use std::sync::Mutex;
-use std::time::Duration;
 
 use domain::base::iana::{Rcode, Rtype};
 use domain::base::message::Message;
@@ -14,10 +12,6 @@ use domain::base::name::{Dname, ToDname};
 use domain::base::octets::Octets512;
 use domain::base::question::Question;
 use domain::rdata::A;
-use lru_time_cache::LruCache;
-
-const DEFAULT_CACHE_EXPIRE: Duration = Duration::from_secs(10 * 60);
-const DEFAULT_CACHE_CAPACITY: usize = 1024;
 
 #[cfg(feature = "slings-runtime")]
 use slings::{
@@ -45,7 +39,6 @@ pub struct Resolver {
     preferred: ServerList,
     stream: ServerList,
     options: ResolvOptions,
-    lru_cache: Arc<Mutex<LruCache<String, Vec<IpAddr>>>>,
 }
 
 impl Resolver {
@@ -58,10 +51,6 @@ impl Resolver {
             preferred: ServerList::from_conf(&conf, |s| s.transport.is_preferred()),
             stream: ServerList::from_conf(&conf, |s| s.transport.is_stream()),
             options: conf.options,
-            lru_cache: Arc::new(Mutex::new(LruCache::with_expiry_duration_and_capacity(
-                DEFAULT_CACHE_EXPIRE,
-                DEFAULT_CACHE_CAPACITY,
-            ))),
         }
     }
 
@@ -75,19 +64,8 @@ impl Resolver {
             .await
     }
 
-    fn try_resolve_from_cache(&self, key: &str) -> Option<Vec<IpAddr>> {
-        self.lru_cache.lock().unwrap().get(key).cloned()
-    }
-
-    fn insert_into_cache(&self, key: &str, val: Vec<IpAddr>) {
-        self.lru_cache.lock().unwrap().insert(key.to_string(), val);
-    }
-
     pub async fn lookup_host<T: AsRef<str>>(&self, host: T) -> io::Result<Vec<IpAddr>> {
         let host = &host.as_ref();
-        if let Some(v) = self.try_resolve_from_cache(host) {
-            return Ok(v);
-        }
 
         let qname = &Dname::<Vec<u8>>::from_str(host)
             .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
@@ -104,7 +82,6 @@ impl Resolver {
                 ips.push(record.data().addr().into());
             }
         }
-        self.insert_into_cache(host, ips.clone());
         Ok(ips)
     }
 
